@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-6
+# Application Name - Health Check V0.5.0-7
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -363,7 +363,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-6 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.0-7 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -445,14 +445,22 @@ class Ui_MainWindow(object):
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
         elif g.strip() == "2.2009.51-1":
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1")
+        elif g.strip() == "2009.51-1.203.2":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Generic Version")
+        elif g.strip() == "2009.51-1.203.1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Generic Version")
+        elif g.strip() == "2009.51-1.205.1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Vodafone Version")
+        elif g.strip() == "2009.51-1.205.2":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Vodafone Version")
         elif g.strip() == "1.2009.44-1":
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.01")
         elif g.strip() == "1.2009.42-11":
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 - Initial public release ")
         elif g.strip() == "1.2009.42-11.002":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 USA Variant ")
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 USA Version")
         elif g.strip() == "1.2009.42-11.003":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 Mid-East/N-Africa Variant")
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 Mid-East/N-Africa Version")
         elif g.strip() == "1.2009.42-11.203":
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.0":
@@ -583,7 +591,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-6", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-7", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
